nextProps property

  1. @override
  2. @Deprecated('Only supported in the deprecated Component, and not in Component2. See doc comment for more info.')
Map get nextProps
override

Do not use.

Will be removed when Component is removed in a future major release.

Implementation

@override
@Deprecated('Only supported in the deprecated Component, and not in Component2. See doc comment for more info.')
Map get nextProps => throw _unsupportedError('nextProps');
  1. @override
set nextProps (Map? _)
override

Reference to the value of props for the upcoming render cycle.

Used internally for proxying ReactJS lifecycle methods shouldComponentUpdate, componentWillReceiveProps, and componentWillUpdate as well as the context-specific variants.

DO NOT set from anywhere outside react-dart lifecycle internals.

Implementation

@override
set nextProps(_) => throw _unsupportedError('nextProps');