setState method
Triggers a rerender with new state obtained by shallow-merging newState into the current state.
Optionally accepts a callback that gets called after the component updates.
To use a transactional setState callback, check out setStateWithUpdater.
Implementation
@override
void setState(Map? newState, [SetStateCallback? callback]) {
_bridge.setState(this, newState, callback);
}